# -*- coding: utf-8 -*-
# Copyright (C) 2021-2022 Greenbone Networks GmbH
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import unittest

from gvm.utils import is_list_like


class TestIsListLike(unittest.TestCase):
    def test_is_list_like(self):
        self.assertFalse(is_list_like(True))

        self.assertFalse(is_list_like("foo"))

        self.assertFalse(is_list_like(13))

        self.assertTrue(is_list_like([1]))

        self.assertTrue(is_list_like(["1", "2"]))

        self.assertTrue(is_list_like(("2", "3")))


if __name__ == "__main__":
    unittest.main()
